import bpy

class MspGLMeshProperties(bpy.types.Panel):
	bl_idname = "MESH_PT_mspgl_properties"
	bl_label = "MspGL properties"
	bl_space_type = "PROPERTIES"
	bl_region_type = "WINDOW"
	bl_context = "data"

	@classmethod
	def poll(cls, context):
		return context.active_object.type=="MESH"

	def draw(self, context):
		mesh = context.active_object.data

		self.layout.prop(mesh, "winding_test")

class MspGLObjectProperties(bpy.types.Panel):
	bl_idname = "OBJECT_PT_mspgl_properties"
	bl_label = "MspGL properties"
	bl_space_type = "PROPERTIES"
	bl_region_type = "WINDOW"
	bl_context = "object"

	def draw(self, context):
		obj = context.active_object

		self.layout.prop(obj, "technique");
		self.layout.prop(obj, "inherit_tech");
		if obj.inherit_tech:
			self.layout.prop(obj, "override_material");
		self.layout.prop(obj, "compound");
		self.layout.prop(obj, "lod_for_parent")
		if obj.lod_for_parent:
			self.layout.prop(obj, "lod_index")

class MspGLMaterialProperties(bpy.types.Panel):
	bl_idname = "MATERIAL_PT_mspgl_properties"
	bl_label = "MspGL properties"
	bl_space_type = "PROPERTIES"
	bl_region_type = "WINDOW"
	bl_context = "material"

	@classmethod
	def poll(cls, context):
		return context.active_object.active_material is not None

	def draw(self, context):
		mat = context.active_object.active_material
		if not mat:
			return

		self.layout.prop(mat, "array_atlas");
		if mat.array_atlas:
			self.layout.prop(mat, "array_layer");

def register_properties():
	bpy.types.Mesh.winding_test = bpy.props.BoolProperty(name="Winding test", description="Perform winding test to skip back faces")
	bpy.types.Object.technique = bpy.props.StringProperty(name="Technique", description="Name of the technique to use for rendering")
	bpy.types.Object.inherit_tech = bpy.props.BoolProperty(name="Inherit technique", description="Inherit from the technique to customize textures")
	bpy.types.Object.override_material = bpy.props.BoolProperty(name="Override material", description="Override material in the inherited technique as well", default=True)
	bpy.types.Object.compound = bpy.props.BoolProperty(name="Compound with parent", description="Join this object to its parent when exporting")
	bpy.types.Object.lod_for_parent = bpy.props.BoolProperty(name="LoD for parent", description="This object is a level of detail for its parent")
	bpy.types.Object.lod_index = bpy.props.IntProperty(name="LoD index", description="Index of the level of detail", min=1, default=1)
	bpy.types.Material.array_atlas = bpy.props.BoolProperty(name="Texture array atlas", description="The material is stored in a texture array")
	bpy.types.Material.array_layer = bpy.props.IntProperty("Texture array layer", description="Layer of the texture array atlas to use")
